@@ -1,7 +1,7 @@
 import json
 import logging
 from pathlib import PurePath
-from subprocess import PIPE, Popen, SubprocessError
+from subprocess import PIPE, Popen
 
 from pylsp import hookimpl, lsp
 from pylsp._utils import find_parents
@@ -91,15 +91,18 @@ def run_ruff_lint(ruff_executable: str, document: Document, arguments: list) ->
         cmd = [ruff_executable]
         cmd.extend(arguments)
         p = Popen(cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE)
-    except SubprocessError as e:
+        (stdout, stderr) = p.communicate(document.source.encode())
+
+        if stderr:
+            log.error(f"Error running ruff: {stderr.decode()}")
+
+        return stdout.decode()
+    except Exception as e:
         # Ruff doesn't yet support calling with python -m ruff,
         # see https://github.com/charliermarsh/ruff/issues/593
         log.error(f"Error running {ruff_executable}: {e}")
-    (stdout, stderr) = p.communicate(document.source.encode())
 
-    if stderr:
-        log.error(f"Error running ruff: {stderr.decode()}")
-    return stdout.decode()
+        return ""
 
 
 def parse_ruff_stdout(stdout: str) -> list:
